@@ -1,4 +1,5 @@
-"""aiding.py constants and basic functions
+"""
+navigating.py constants and basic functions for navigation
 
 """
 from __future__ import absolute_import, division, print_function
@@ -12,14 +13,14 @@ from .sixing import *
 from .odicting import odict
 from ..base import excepting
 
-from ..base.consoling import getConsole
+from .consoling import getConsole
 console = getConsole()
 
 TWOPI = 2.0 * math.pi  # two times pi
 DEGTORAD = math.pi / 180.0  # r = DEGTORAD * d
 RADTODEG = 180.0 / math.pi  # d = RADTODEG * r
 
-def Sign(x):
+def sign(x):
     """Calculates the sign of a number and returns
        1 if positive
        -1 if negative
@@ -33,19 +34,9 @@ def Sign(x):
     else:
         return 0.0
 
+Sign = sign
 
-def Delta(desired, actual, wrap = 180.0):
-    """Calculate the short rotation for delta = desired - actual
-       and delta wraps around at wrap
-
-    """
-    #delta = desired  - actual  so
-    #desired  = actual  + delta
-
-    return Wrap2(angle = (desired - actual), wrap = wrap)
-
-
-def Wrap2(angle, wrap = 180.0):
+def wrap2(angle, wrap = 180.0):
     """Wrap2 = (2 sided one positive one negative) wrap of angle to
        signed interval [-wrap, + wrap] wrap is half circle
        if wrap = 0 then don't wrap
@@ -78,8 +69,23 @@ def Wrap2(angle, wrap = 180.0):
 
     return angle
 
+Wrap2 = wrap2
 
-def MoveByHSD(heading = 0.0, speed = 1.0, duration = 0.0):
+
+def delta(desired, actual, wrap = 180.0):
+    """Calculate the short rotation for delta = desired - actual
+       and delta wraps around at wrap
+
+    """
+    #delta = desired  - actual  so
+    #desired  = actual  + delta
+
+    return wrap2(angle = (desired - actual), wrap = wrap)
+
+Delta = delta
+
+
+def moveByHSD(heading = 0.0, speed = 1.0, duration = 0.0):
     """
        Returns change in position after moving on heading at speed for duration
        heading in compass coordinates, 0 deg is north, up, cw rotation increases
@@ -89,6 +95,8 @@ def MoveByHSD(heading = 0.0, speed = 1.0, duration = 0.0):
 
     return (deltaNorth, deltaEast)
 
+MoveByHSD = moveByHSD
+
 def MoveToHSD(north = 0.0, east = 0.0,
               heading = 0.0, speed = 1.0, duration = 0.0):
     """
@@ -148,11 +156,11 @@ def AlongCrossTrack(track = 0.0, north = 0.0, east = 0.0,
        a negative cross track is to the west of the track
     """
     if mag is not None and heading is not None:
-        heading = Wrap2(heading)
+        heading = wrap2(heading)
         north = mag * math.cos(DEGTORAD * heading)
         east = mag * math.sin(DEGTORAD * heading)
 
-    track = Wrap2(track)
+    track = wrap2(track)
 
     #along track component
     trackNorth = math.cos(DEGTORAD * track)
@@ -202,11 +210,11 @@ def CrabSpeed(track = 0.0,  speed = 2.0, north = 0.0, east = 0.0,
        of the desired course
     """
     if mag is not None and heading is not None:
-        heading = Wrap2(heading)
+        heading = wrap2(heading)
         north = mag * math.cos(DEGTORAD * heading)
         east = mag * math.sin(DEGTORAD * heading)
 
-    track = Wrap2(track)
+    track = wrap2(track)
     (A,C) = AlongCrossTrack(track = track, north = north, east = east)
     #current compensated course crab = track + delta crab angle
     delta = - RADTODEG * math.asin(C / speed)
@@ -304,13 +312,17 @@ def SphereLLLLToDNDE(lat0,lon0,lat1,lon1):
 
     return (dn, de)
 
-def SphereLLByDNDEToLL(lat0,lon0,dn,de):
-    """Computes new lat lon location on sphere
-       from the flat earth approx of  change in position dn (north) meters
-       and de (east) meters from the given location lat0 lon0
-       point lat0 lon0  in total fractional degrees north east positive
-       returns tuple (lat1,lon1)
-       Uses sphere 1 nm = 1 minute 1852 meters per nautical mile
+def sphereLLByDNDEToLL(lat0, lon0, dn, de):
+    """
+    Returns new lat lon location on sphere in total fractional
+    degrees north east positive
+    Using the flat earth approx of sphere
+    given relative position dn (north) meters and de (east) meters
+    from the given location lat0 lon0
+
+    returns tuple (lat1,lon1)
+
+    Uses sphere 1 nm = 1 minute 1852 meters per nautical mile
     """
     r = 6366710.0 #radius of earth in meters = 1852 * 60 * 180/pi
 
@@ -329,6 +341,8 @@ def SphereLLByDNDEToLL(lat0,lon0,dn,de):
 
     return (lat1, lon1)
 
+SphereLLByDNDEToLL = sphereLLByDNDEToLL
+
 def SphereLLbyRBtoLL(lat0,lon0,range,bearing):
     """Computes new lat lon location on sphere
         from the flat earth approx of  change in range meters at bearing degrees from
@@ -413,10 +427,10 @@ def DegMinToFracDeg(latDeg, latMin, lonDeg, lonMin):
        lonDeg are in signed degrees East positive West Negative
        lonMin are in signed minutes East positive West Negative
     """
-    if Sign(latDeg) != Sign(latMin):
+    if sign(latDeg) != sign(latMin):
         latMin = - latMin
 
-    if Sign(lonDeg) != Sign(lonMin):
+    if sign(lonDeg) != sign(lonMin):
         lonMin =  - lonMin
 
     lat = latDeg + (latMin / 60.0)
